Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_, and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

The changes listed in this file are categorised as follows:

    - Added: new features
    - Changed: changes in existing functionality
    - Deprecated: soon-to-be removed features
    - Removed: now removed features
    - Fixed: any bug fixes
    - Security: in case of vulnerabilities.

v0.2.3 - 2021-04-27
-------------------

Fixed
~~~~~

- (`#34 <https://github.com/openscm/openscm-twolayermodel/pull/34>`_, `#35 <https://github.com/openscm/openscm-twolayermodel/pull/35>`_, `#36 <https://github.com/openscm/openscm-twolayermodel/pull/36>`_) Final tweaks to JOSS paper

v0.2.2 - 2021-04-27
-------------------

Added
~~~~~

- (`#33 <https://github.com/openscm/openscm-twolayermodel/pull/33>`_) Information in README and testing for conda install

Changed
~~~~~~~

- (`#32 <https://github.com/openscm/openscm-twolayermodel/pull/32>`_) Include ``LICENSE``, ``README.rst`` and ``CHANGELOG`` in package
- (`#30 <https://github.com/openscm/openscm-twolayermodel/pull/30>`_) Require ``scmdata>=0.9``
- (`#27 <https://github.com/openscm/openscm-twolayermodel/pull/27>`_) Fixed the discussion (in the relevant notebook) of how a one-layer model can be made from the two-layer implementation here

Fixed
~~~~~

- (`#30 <https://github.com/openscm/openscm-twolayermodel/pull/30>`_) Incorrect call to :meth:`scmdata.ScmRun` in tests

v0.2.1 - 2020-12-23
-------------------

Added
~~~~~

- (`#20 <https://github.com/openscm/openscm-twolayermodel/pull/20>`_) Statement of need to the README following `JOSS review <https://github.com/openjournals/joss-reviews/issues/2766>`_ (closes `#18 <https://github.com/openscm/openscm-twolayermodel/issues/18>`_)

Changed
~~~~~~~

- (`#26 <https://github.com/openscm/openscm-twolayermodel/pull/26>`_) Updated to new scmdata version (and hence new openscm-units API)
- (`#25 <https://github.com/openscm/openscm-twolayermodel/pull/25>`_) JOSS paper following `JOSS review 1 <https://github.com/openjournals/joss-reviews/issues/2766#issuecomment-718025503>`_
- (`#23 <https://github.com/openscm/openscm-twolayermodel/pull/23>`_) Moved notebooks into full documentation following `JOSS review <https://github.com/openjournals/joss-reviews/issues/2766>`_ (closes `#17 <https://github.com/openscm/openscm-twolayermodel/issues/17>`_)
- (`#21 <https://github.com/openscm/openscm-twolayermodel/pull/21>`_) Quoted pip install instructions to ensure cross-shell compatibility following `JOSS review <https://github.com/openjournals/joss-reviews/issues/2766>`_ (closes `#16 <https://github.com/openscm/openscm-twolayermodel/issues/16>`_)
- (`#20 <https://github.com/openscm/openscm-twolayermodel/pull/20>`_) Option to remove tqdm progress bar by passing ``progress=False``

v0.2.0 - 2020-10-09
-------------------

Added
~~~~~

- (`#7 <https://github.com/openscm/openscm-twolayermodel/pull/7>`_) JOSS paper draft

Changed
~~~~~~~

- (`#7 <https://github.com/openscm/openscm-twolayermodel/pull/7>`_) Require ``scmdata>=0.7``

v0.1.2 - 2020-31-07
-------------------

Changed
~~~~~~~

- (`#12 <https://github.com/openscm/openscm-twolayermodel/pull/12>`_) Upgrade to ``scmdata>=0.6.2`` so that package can be installed

v0.1.1 - 2020-06-29
-------------------

Added
~~~~~

- (`#8 <https://github.com/openscm/openscm-twolayermodel/pull/8>`_) Add notebook showing how to run a single-layer model

Changed
~~~~~~~

- (`#11 <https://github.com/openscm/openscm-twolayermodel/pull/11>`_) Re-wrote the getting started notebook
- (`#10 <https://github.com/openscm/openscm-twolayermodel/pull/10>`_) Re-wrote CHANGELOG
- (`#9 <https://github.com/openscm/openscm-twolayermodel/pull/9>`_) Update to scmdata 0.5.Y

v0.1.0 - 2020-05-15
-------------------

Added
~~~~~

- (`#3 <https://github.com/openscm/openscm-twolayermodel/pull/3>`_) Add first implementation of the models
- (`#1 <https://github.com/openscm/openscm-twolayermodel/pull/1>`_) Setup repository
